@@ -7,8 +7,8 @@ from os.path import join, dirname, exists, isdir, abspath
 from configparser import ConfigParser
 from multiprocessing import Process
 from utils import get_user_home, get_logged_user, \
-                    get_package_version, getoutput, shell_exec, \
-                    get_lsb_release_info, is_package_installed
+                  get_package_version, getoutput, shell_exec, \
+                  get_lsb_release_info
 from dialogs import message_dialog, error_dialog, \
                     SelectFileDialog, SelectDirectoryDialog, \
                     question_dialog
@@ -80,9 +80,10 @@ class Constructor():
         self.window.set_default_size(window_width, window_height)
         self.dt_paned.set_position(distros_height)
 
-        # Remove old log file
+        # Re-initialize the log file
         if exists(self.log_file):
             remove(self.log_file)
+            shell_exec(f'sudo -u {self.user_name} touch "{self.log_file}"')
 
         # Main window objects
         self.tv_distros = builder_obj('tv_distros')
