@@ -4,7 +4,7 @@
 import sys
 import traceback
 from dialogs import error_dialog
-from construcor import Constructor
+from constructor import Constructor
 
 # Make sure the right Gtk version is loaded
 import gi
