@@ -350,8 +350,9 @@ if [ -e "$GRUB_THEME" ]; then
     GRUB_DEFAULT='GRUB_DEFAULT=saved\nGRUB_SAVEDEFAULT=true\nGRUB_HIDDEN_TIMEOUT_QUIET=true'
     sed -i -e "s|^GRUB_DEFAULT=0|$GRUB_DEFAULT|" $DEFAULT_GRUB
 
-    [ ! -z "$DESCRIPTION" ] && GRUB_DISTRIBUTOR=$DESCRIPTION || GRUB_DISTRIBUTOR='SolydXK'
-    sed -i -e "s/GRUB_DISTRIBUTOR=.*/GRUB_DISTRIBUTOR=\"$GRUB_DISTRIBUTOR\"/" $DEFAULT_GRUB
+    #[ ! -z "$DESCRIPTION" ] && GRUB_DISTRIBUTOR=$DESCRIPTION || GRUB_DISTRIBUTOR='SolydXK'
+    #sed -i -e "s/GRUB_DISTRIBUTOR=.*/GRUB_DISTRIBUTOR=\"$GRUB_DISTRIBUTOR\"/" $DEFAULT_GRUB
+    sed -i 's#GRUB_DISTRIBUTOR=.*#GRUB_DISTRIBUTOR=`cat /etc/issue.net 2>/dev/null || echo SolydXK`#' $DEFAULT_GRUB
 
     sed -i -e 's|"quiet"|"quiet splash"|' $DEFAULT_GRUB
 fi
